documentStore.BdbDocumentStore

|  | ## Cheshire3 Object Model: Class BdbDocumentStore

Module documentStore :: Class BdbDocumentStore

## Class BdbDocumentStore
source code

Object Tree:

                   object --+
                            |
        configParser.C3Object --+
                                |
                      SimpleStore --+
                                    |
                   baseStore.BdbStore --+
                                        |
               object --+               |
                        |               |
    configParser.C3Object --+           |
                            |           |
                  ObjectStore --+       |
                                |       |
        baseObjects.DocumentStore --+   |
                                    |   |
                  SimpleDocumentStore --+
                                        |
                                       BdbDocumentStore

Instance Methods

__init__(self, session, node, parent) The constructor for all Cheshire3 objects take the same arguments: session: A Session object topNode: The <config> or <subConfig> domNode for the configuration parent: The object that provides the scope for this object.
__iter__(self)
Inherited from `baseStore.BdbStore`: `begin_storing`, `clean`, `commit_storing`, `delete_item`, `fetch_checksum`, `fetch_data`, `fetch_idList`, `fetch_size`, `generate_id`, `get_dbsize`, `store_checkSum`, `store_data`, `verify_checkSum` Inherited from `baseStore.BdbStore` (private): `_closeContainer`, `_initialise`, `_openContainer`, `_verifyDatabase`, `_verifyDatabases` Inherited from `SimpleDocumentStore`: `create_document`, `delete_document`, `fetch_document`, `store_document` Inherited from `baseObjects.DocumentStore`: `fetch_documentList` Inherited from `baseObjects.ObjectStore`: `create_object`, `delete_object`, `fetch_object`, `store_object` Inherited from `configParser.C3Object`: `auth_function`, `get_config`, `get_default`, `get_object`, `get_path`, `get_setting`, `log_function`, `unauth_function`, `unlog_function` Inherited from `configParser.C3Object` (private): `_getDomFromFile`, `_handleConfigNode`, `_parseIncludes`, `_recurseSubConfigs`, `_verifyDefault`, `_verifyOption`, `_verifySetting` Inherited from `object`: `__delattr__`, `__getattribute__`, `__hash__`, `__new__`, `__reduce__`, `__reduce_ex__`, `__repr__`, `__setattr__`, `__str__`

Class Variables

Inherited from `baseStore.BdbStore`: `cxn`, `digestCxn`, `digestForId` Inherited from `baseStore.SimpleStore`: `currentId`, `idNormalizer` Inherited from `SimpleDocumentStore`: `inPreParser`, `inWorkflow`, `outPreParser`, `outWorkflow` Inherited from `configParser.C3Object`: `configStore`, `defaults`, `functionLogger`, `id`, `name`, `objectType`, `objects`, `parent`, `paths`, `permissionHandlers`, `settings`, `subConfigs`, `unresolvedObjects` Inherited from `configParser.C3Object` (private): `_includeConfigStores`, `_objectRefs` Inherited from `object`: `__class__`

Method Details

### __init__(self, session, node, parent) (Constructor) | source code
The constructor for all Cheshire3 objects take the same arguments: session: A Session object topNode: The <config> or <subConfig> domNode for the configuration parent: The object that provides the scope for this object. Overrides: baseStore.SimpleStore.__init__

### __iter__(self) | source code
Overrides: baseStore.BdbStore.__iter__